@@ -1,9 +1,9 @@
 package BenchmarkAnything::Storage::Backend::SQL;
-# git description: v0.016-1-g1e62d47
+# git description: v0.017-4-g5ae3d31
 
 our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Autonomous SQL backend to store benchmarks
-$BenchmarkAnything::Storage::Backend::SQL::VERSION = '0.017';
+$BenchmarkAnything::Storage::Backend::SQL::VERSION = '0.018';
 use 5.008;
 use strict;
 use warnings;
@@ -532,14 +532,16 @@ sub get_stats {
 
     my ( $or_self ) = @_;
 
-    my $i_count_datapoints = $or_self->{query}->select_count_datapoints->fetch->[0];
-    my $i_count_metrics    = $or_self->{query}->select_count_metrics->fetch->[0];
-    my $i_count_keys       = $or_self->{query}->select_count_keys->fetch->[0];
+    my $i_count_datapointkeys = $or_self->{query}->select_count_datapointkeys->fetch->[0];
+    my $i_count_datapoints    = $or_self->{query}->select_count_datapoints->fetch->[0];
+    my $i_count_metrics       = $or_self->{query}->select_count_metrics->fetch->[0];
+    my $i_count_keys          = $or_self->{query}->select_count_keys->fetch->[0];
 
     return {
-        count_datapoints => 0+$i_count_datapoints,
-        count_metrics    => 0+$i_count_metrics,
-        count_keys       => 0+$i_count_keys,
+        count_datapointkeys => 0+$i_count_datapointkeys,
+        count_datapoints    => 0+$i_count_datapoints,
+        count_metrics       => 0+$i_count_metrics,
+        count_keys          => 0+$i_count_keys,
     };
 }
 
@@ -574,6 +576,8 @@ sub get_single_benchmark_point {
     $hr_result          = { map { ($_->{bench_additional_type} => $_->{bench_additional_value} ) } @$ar_query_result };
     $hr_result->{NAME}  = $hr_essentials->{bench};
     $hr_result->{VALUE} = $hr_essentials->{bench_value};
+    $hr_result->{VALUE_ID} = $hr_essentials->{bench_value_id};
+    $hr_result->{CREATED_AT} = $hr_essentials->{created_at};
     $hr_result->{UNIT}  = $hr_essentials->{bench_unit} if $hr_essentials->{bench_unit};
 
     # cache!
