@@ -1,7 +1,7 @@
 package BenchmarkAnything::Storage::Backend::SQL::Query::common;
 our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: BenchmarkAnything::Storage::Backend::SQL - querying - backend base class
-$BenchmarkAnything::Storage::Backend::SQL::Query::common::VERSION = '0.017';
+$BenchmarkAnything::Storage::Backend::SQL::Query::common::VERSION = '0.018';
 use strict;
 use warnings;
 use base 'BenchmarkAnything::Storage::Backend::SQL::Query';
@@ -117,7 +117,9 @@ sub select_benchmark_point_essentials {
     return $or_self->execute_query( "
         SELECT
           b.bench,
+          bv.created_at,
           bv.bench_value,
+          bv.bench_value_id,
           bu.bench_unit
         FROM
           $or_self->{config}{tables}{benchmark_table} b
@@ -391,6 +393,12 @@ sub select_count_keys {
     return $or_self->execute_query( "SELECT COUNT(1) FROM $or_self->{config}{tables}{additional_type_table}" );
 }
 
+sub select_count_datapointkeys {
+    my ( $or_self, @a_vals ) = @_;
+
+    return $or_self->execute_query( "SELECT COUNT(1) FROM $or_self->{config}{tables}{additional_relation_table}" );
+}
+
 sub select_unit {
 
     my ( $or_self, @a_vals ) = @_;
